==> forestry_1.12.2-5.8.0.260-sources.jar: forestry/plugins/PluginBetterWithMods.java <==
package forestry.plugins;

import net.minecraft.block.Block;
import net.minecraft.block.BlockCrops;
import net.minecraft.block.properties.PropertyBool;
import net.minecraft.block.properties.PropertyInteger;
import net.minecraft.block.state.IBlockState;
import net.minecraft.item.ItemStack;

import forestry.api.core.ForestryAPI;
import forestry.api.farming.IFarmRegistry;
import forestry.api.modules.ForestryModule;
import forestry.api.recipes.RecipeManagers;
import forestry.core.config.Constants;
import forestry.core.fluids.Fluids;
import forestry.farming.logic.farmables.FarmableDoubleCrop;
import forestry.modules.ForestryModuleUids;

@SuppressWarnings("unused")
@ForestryModule(containerID = ForestryCompatPlugins.ID, moduleID = ForestryModuleUids.BETTER_WITH_MODS, name = "Better With Mods", author = "Nedelosk", url = Constants.URL, unlocalizedDescription = "for.module.betterwithmods.description")
public class PluginBetterWithMods extends CompatPlugin {
	public PluginBetterWithMods() {
		super("Better With Mods", "betterwithmods");
	}

	@Override
	public void registerRecipes() {
		IFarmRegistry farmRegistry = ForestryAPI.farmRegistry;
		int seedAmount = ForestryAPI.activeMode.getIntegerSetting("squeezer.liquid.seed");
		PropertyBool TOP = PropertyBool.func_177716_a("top");
		PropertyInteger AGE = BlockCrops.field_176488_a;
		ItemStack hempSeed = getItemStack("hemp");
		Block hempCrop = getBlock("hemp");

		if (hempSeed != null && hempCrop != null) {
			IBlockState defaultState = hempCrop.func_176223_P();
			IBlockState planted = defaultState.func_177226_a(AGE, 0).func_177226_a(TOP, false);
			IBlockState mature = defaultState.func_177226_a(AGE, 7).func_177226_a(TOP, false);
			IBlockState topMature = defaultState.func_177226_a(AGE, 7).func_177226_a(TOP, true);

			farmRegistry.registerFarmables("farmCrops", new FarmableDoubleCrop(hempSeed, planted, mature, topMature, true));

			RecipeManagers.squeezerManager.addRecipe(10, hempSeed, Fluids.SEED_OIL.getFluid(seedAmount));
		}
	}
}

==> forestry_1.12.2-5.8.2.408-sources.jar: forestry/plugins/PluginBetterWithMods.java <==
package forestry.plugins;

import net.minecraft.block.Block;
import net.minecraft.block.BlockCrops;
import net.minecraft.block.properties.PropertyBool;
import net.minecraft.block.properties.PropertyInteger;
import net.minecraft.block.state.IBlockState;
import net.minecraft.item.ItemStack;

import forestry.api.core.ForestryAPI;
import forestry.api.farming.IFarmRegistry;
import forestry.api.modules.ForestryModule;
import forestry.api.recipes.RecipeManagers;
import forestry.core.config.Constants;
import forestry.core.fluids.Fluids;
import forestry.farming.logic.ForestryFarmIdentifier;
import forestry.farming.logic.farmables.FarmableDoubleCrop;
import forestry.modules.ForestryModuleUids;

@SuppressWarnings("unused")
@ForestryModule(containerID = ForestryCompatPlugins.ID, moduleID = ForestryModuleUids.BETTER_WITH_MODS, name = "Better With Mods", author = "Nedelosk", url = Constants.URL, unlocalizedDescription = "for.module.betterwithmods.description")
public class PluginBetterWithMods extends CompatPlugin {
	public PluginBetterWithMods() {
		super("Better With Mods", "betterwithmods");
	}

	@Override
	public void registerRecipes() {
		IFarmRegistry farmRegistry = ForestryAPI.farmRegistry;
		int seedAmount = ForestryAPI.activeMode.getIntegerSetting("squeezer.liquid.seed");
		PropertyBool TOP = PropertyBool.func_177716_a("top");
		PropertyInteger AGE = BlockCrops.field_176488_a;
		ItemStack hempSeed = getItemStack("hemp");
		Block hempCrop = getBlock("hemp");

		if (hempSeed != null && hempCrop != null) {
			IBlockState defaultState = hempCrop.func_176223_P();
			IBlockState planted = defaultState.func_177226_a(AGE, 0).func_177226_a(TOP, false);
			IBlockState mature = defaultState.func_177226_a(AGE, 7).func_177226_a(TOP, false);
			IBlockState topMature = defaultState.func_177226_a(AGE, 7).func_177226_a(TOP, true);

			farmRegistry.registerFarmables(ForestryFarmIdentifier.CROPS, new FarmableDoubleCrop(hempSeed, planted, mature, topMature, true));

			RecipeManagers.squeezerManager.addRecipe(10, hempSeed, Fluids.SEED_OIL.getFluid(seedAmount));
		}
	}
}
